==> Tridium_EMEA_N4_Supervisor-4.10.11.12.zip: rc/widget/LiveVideoPlayerWidget.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
/**
 * @copyright 2019 Tridium, Inc. All Rights Reserved.
 * @author Bhavani Patnam
 */

/* eslint-env browser */
/**
 * API Status: **Private**
 * @module nmodule/videoDriver/rc/widget/LiveVideoPlayerWidget
 */
define(['baja!', 'bajaux/Widget', 'bajaux/mixin/subscriberMixIn', 'underscore', 'nmodule/webEditors/rc/fe/fe', 'nmodule/videoDriver/rc/live/LiveVideo', 'css!nmodule/videoDriver/rc/videoDriver'], function (baja, Widget, subscriberMixIn, _, fe, LiveVideo) {
  'use strict';

  var tpl = function tpl() {
    return " \n    <div class='LiveVideoContainer'></div> \n ";
  };

  /**
   * Shows the Live Video Player Widget
   * LiveVideoPlayerWidget
   *
   * @class
   * @alias module:nmodule/videoDriver/rc/widget/LiveVideoPlayerWidget
   * @extends module:bajaux/Widget
   */
  var LiveVideoPlayerWidget = /*#__PURE__*/function (_Widget) {
    function LiveVideoPlayerWidget(params) {
      var _this;
      _classCallCheck(this, LiveVideoPlayerWidget);
      _this = _callSuper(this, LiveVideoPlayerWidget, [_.extend({
        keyName: 'LiveVideoPlayerWidget',
        moduleName: 'videoDriver'
      }, {}, params)]);
      subscriberMixIn(_this);
      return _this;
    }

    /**
     * Adds `LiveVideoPlayerWidget` class to dom
     * @param {JQuery} dom
     */
    _inherits(LiveVideoPlayerWidget, _Widget);
    return _createClass(LiveVideoPlayerWidget, [{
      key: "doInitialize",
      value: function doInitialize(dom) {
        dom.html(tpl()).addClass('LiveVideoPlayerWidget');
      }

      /**
       * Shows LiveVideoPlayerWidget on the px page and the browser
       *
       * @returns {Promise}
       */
    }, {
      key: "doLoad",
      value: function doLoad(value) {
        return fe.buildFor({
          value: value,
          formFactor: 'max',
          dom: this.$getLiveVideoContainer(),
          type: LiveVideo,
          properties: {
            showPtzAndPresets: false
          }
        });
      }
    }, {
      key: "$getLiveVideoContainer",
      value:
      /**
       * Gets the jquery element of the LiveVideoContainer.
       * @private
       * @returns {JQuery}
       */
      function $getLiveVideoContainer() {
        return this.jq().find('.LiveVideoContainer');
      }

      /**
       *Removes `LiveVideoPlayerWidget` class.
       */
    }, {
      key: "doDestroy",
      value: function doDestroy() {
        this.jq().removeClass('LiveVideoPlayerWidget');
      }
    }]);
  }(Widget);
  return LiveVideoPlayerWidget;
});

==> Tridium_EMEA_N4_Supervisor-4.14.3.24.zip: rc/widget/LiveVideoPlayerWidget.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
/**
 * @copyright 2019 Tridium, Inc. All Rights Reserved.
 * @author Bhavani Patnam
 */

/* eslint-env browser */
/**
 * API Status: **Private**
 * @module nmodule/videoDriver/rc/widget/LiveVideoPlayerWidget
 */
define(['baja!', 'bajaux/Widget', 'bajaux/mixin/subscriberMixIn', 'underscore', 'nmodule/webEditors/rc/fe/fe', 'nmodule/videoDriver/rc/live/LiveVideo', 'css!nmodule/videoDriver/rc/videoDriver'], function (baja, Widget, subscriberMixIn, _, fe, LiveVideo) {
  'use strict';

  var tpl = function tpl() {
    return " \n    <div class='LiveVideoContainer'></div> \n ";
  };

  /**
   * Shows the Live Video Player Widget
   * LiveVideoPlayerWidget
   *
   * @class
   * @alias module:nmodule/videoDriver/rc/widget/LiveVideoPlayerWidget
   * @extends module:bajaux/Widget
   */
  var LiveVideoPlayerWidget = /*#__PURE__*/function (_Widget) {
    function LiveVideoPlayerWidget(params) {
      var _this;
      _classCallCheck(this, LiveVideoPlayerWidget);
      _this = _callSuper(this, LiveVideoPlayerWidget, [_.extend({
        keyName: 'LiveVideoPlayerWidget',
        moduleName: 'videoDriver'
      }, {}, params)]);
      subscriberMixIn(_this);
      return _this;
    }

    /**
     * Adds `LiveVideoPlayerWidget` class to dom
     * @param {JQuery} dom
     */
    _inherits(LiveVideoPlayerWidget, _Widget);
    return _createClass(LiveVideoPlayerWidget, [{
      key: "doInitialize",
      value: function doInitialize(dom) {
        dom.html(tpl()).addClass('LiveVideoPlayerWidget');
      }

      /**
       * Shows LiveVideoPlayerWidget on the px page and the browser
       *
       * @returns {Promise}
       */
    }, {
      key: "doLoad",
      value: function doLoad(value) {
        return fe.buildFor({
          value: value,
          formFactor: 'max',
          dom: this.$getLiveVideoContainer(),
          type: LiveVideo,
          properties: {
            showPtzAndPresets: false
          }
        });
      }

      /**
       * Gets the jquery element of the LiveVideoContainer.
       * @private
       * @returns {JQuery}
       */
    }, {
      key: "$getLiveVideoContainer",
      value: function $getLiveVideoContainer() {
        return this.jq().find('.LiveVideoContainer');
      }

      /**
       *Removes `LiveVideoPlayerWidget` class.
       */
    }, {
      key: "doDestroy",
      value: function doDestroy() {
        this.jq().removeClass('LiveVideoPlayerWidget');
      }
    }]);
  }(Widget);
  return LiveVideoPlayerWidget;
});
